@@ -1,4 +1,5 @@
 import itertools
+import re
 from typing import List
 from typing import Optional
 
@@ -7,6 +8,7 @@ from openapi_schema_pydantic import Components
 from openapi_schema_pydantic import Reference
 from openapi_schema_pydantic import Schema
 
+from openapi_python_generator.language_converters.python import common
 from openapi_python_generator.language_converters.python.jinja_config import (
     ENUM_TEMPLATE,
 )
@@ -33,7 +35,7 @@ def type_converter(schema: Schema, required: bool = False) -> TypeConversion:
         pre_type = "Optional["
         post_type = "]"
 
-    original_type = schema.type
+    original_type = schema.type if schema.type is not None else "object"
     import_types: Optional[List[str]] = None
 
     if schema.allOf is not None:
@@ -42,11 +44,12 @@ def type_converter(schema: Schema, required: bool = False) -> TypeConversion:
             if isinstance(sub_schema, Schema):
                 conversions.append(type_converter(sub_schema, True))
             else:
-                import_types = [sub_schema.ref.split("/")[-1]]
+                import_type = sub_schema.ref.split("/")[-1]
+                import_types = [f"from .{import_type} import {import_type}"]
                 conversions.append(
                     TypeConversion(
                         original_type=sub_schema.ref,
-                        converted_type=import_types[0],
+                        converted_type=import_type,
                         import_types=import_types,
                     )
                 )
@@ -54,13 +57,14 @@ def type_converter(schema: Schema, required: bool = False) -> TypeConversion:
         original_type = (
             "tuple<" + ",".join([i.original_type for i in conversions]) + ">"
         )
-        converted_type = (
-            pre_type
-            + "Tuple["
-            + ",".join([i.converted_type for i in conversions])
-            + "]"
-            + post_type
-        )
+        if len(conversions) == 1:
+            converted_type = conversions[0].converted_type
+        else:
+            converted_type = (
+                "Tuple[" + ",".join([i.converted_type for i in conversions]) + "]"
+            )
+
+        converted_type = pre_type + converted_type + post_type
         import_types = [
             i.import_types[0] for i in conversions if i.import_types is not None
         ]
@@ -73,31 +77,41 @@ def type_converter(schema: Schema, required: bool = False) -> TypeConversion:
             if isinstance(sub_schema, Schema):
                 conversions.append(type_converter(sub_schema, True))
             else:
-                import_types = [sub_schema.ref.split("/")[-1]]
+                import_type = sub_schema.ref.split("/")[-1]
+                import_types = [f"from .{import_type} import {import_type}"]
                 conversions.append(
                     TypeConversion(
                         original_type=sub_schema.ref,
-                        converted_type=import_types[0],
+                        converted_type=import_type,
                         import_types=import_types,
                     )
                 )
         original_type = (
             "union<" + ",".join([i.original_type for i in conversions]) + ">"
         )
-        converted_type = (
-            pre_type
-            + "Union["
-            + ",".join([i.converted_type for i in conversions])
-            + "]"
-            + post_type
-        )
+
+        if len(conversions) == 1:
+            converted_type = conversions[0].converted_type
+        else:
+            converted_type = (
+                "Union[" + ",".join([i.converted_type for i in conversions]) + "]"
+            )
+
+        converted_type = pre_type + converted_type + post_type
         import_types = list(
             itertools.chain(
                 *[i.import_types for i in conversions if i.import_types is not None]
             )
         )
-    elif schema.type == "string":
+    # We only want to auto convert to datetime if orjson is used throghout the code, otherwise we can not
+    # serialize it to JSON.
+    elif schema.type == "string" and (
+        schema.schema_format is None or not common.get_use_orjson()
+    ):
         converted_type = pre_type + "str" + post_type
+    elif schema.type == "string" and schema.schema_format == "date-time":
+        converted_type = pre_type + "datetime" + post_type
+        import_types = ["from datetime import datetime"]
     elif schema.type == "integer":
         converted_type = pre_type + "int" + post_type
     elif schema.type == "number":
@@ -107,7 +121,8 @@ def type_converter(schema: Schema, required: bool = False) -> TypeConversion:
     elif schema.type == "array":
         retVal = pre_type + "List["
         if isinstance(schema.items, Reference):
-            import_types = [schema.items.ref.split("/")[-1]]
+            import_type = schema.items.ref.split("/")[-1]
+            import_types = [f"from .{import_type} import {import_type}"]
             original_type = "array<" + schema.items.ref.split("/")[-1] + ">"
             retVal += schema.items.ref.split("/")[-1]
         elif isinstance(schema.items, Schema):
@@ -177,7 +192,7 @@ def _generate_property_from_reference(
     type_conv = TypeConversion(
         original_type=reference.ref,
         converted_type=import_model if required else "Optional[" + import_model + "]",
-        import_types=[import_model],
+        import_types=[f"from .{import_model} import {import_model}"],
     )
     return Property(
         name=name,
@@ -204,10 +219,16 @@ def generate_models(components: Components) -> List[Model]:
 
     for name, schema_or_reference in components.schemas.items():
         if schema_or_reference.enum is not None:
+            value_dict = schema_or_reference.dict()
+            regex = re.compile(r"[\s\/=\*\+]+")
+            value_dict["enum"] = [
+                re.sub(regex, "_", i) if isinstance(i, str) else f"value_{i}"
+                for i in value_dict["enum"]
+            ]
             m = Model(
                 file_name=name,
                 content=JINJA_ENV.get_template(ENUM_TEMPLATE).render(
-                    name=name, **schema_or_reference.dict()
+                    name=name, **value_dict
                 ),
                 openapi_object=schema_or_reference,
                 properties=[],
